@@ -576,7 +576,7 @@ _ansi_sgr_groups = tuple(
         ((20, 23),),
         (range(30, 40), range(90, 98)),
         (range(40, 50), range(100, 108)),
-        ((26, 50),)
+        ((26, 50),),
         ((51, 54),),
         ((52, 54),),
         ((53, 55),)
